@@ -1,6 +1,6 @@
 """A collection of common stream operations."""
 from ._buffers import Window, Group, Delay
 from ._combiners import Chain, Merge, Zip, ZipLatest
-from ._filters import Skip, Filter, Changes, RateLimit
+from ._filters import Skip, SkipWhile, Filter, Changes, RateLimit
 from ._producers import Repeat
 from ._refiners import Map
